==> foundation-2.6.1.tgz: package/MaleFemale/MaleFemale.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const MaleFemale = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("circle", {
    cx: 22.336,
    cy: 19.721,
    r: 8.272
  }), /*#__PURE__*/React.createElement("path", {
    d: "M37.999 30.217v-.04H8.363v.027a3.895 3.895 0 00-3.894 3.867h-.003V57.51h.039a3.477 3.477 0 106.954 0h.008V41.148h.009a1.104 1.104 0 011.101-1.064c.598 0 1.078.473 1.103 1.064h.009v42.905a4.067 4.067 0 008.136-.005V62.444h.03a1.127 1.127 0 112.253 0h.029v21.604a4.07 4.07 0 008.137 0v-42.9a1.11 1.11 0 112.222 0v16.363h.038a3.478 3.478 0 106.956 0h.007V34.072c.002-2.015-1.535-3.654-3.498-3.855z"
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 72.297,
    cy: 19.768,
    r: 8.32
  }), /*#__PURE__*/React.createElement("path", {
    d: "M95.534 54.161l-5.55-20.712c-.003-.016-.009-.032-.013-.048l-.098-.365-.014.004c-.506-1.579-1.968-2.729-3.715-2.729-.014 0-.026.004-.04.004v-.072h-26.12v.068c-1.747 0-3.209 1.151-3.715 2.729l-.014-.004-.098.364c-.004.017-.01.033-.013.05l-5.55 20.711.052.014c-.025.171-.052.342-.052.52a3.536 3.536 0 003.536 3.536 3.529 3.529 0 003.283-2.244l.025.007 4.071-15.193v.057h.032c.111-.5.536-.882 1.07-.882s.959.382 1.07.882h.033v.164c.002.025.015.047.015.072 0 .025-.013.047-.015.072v.155l-6.518 24.326a1.887 1.887 0 00-.187.698l-.014.051.008.002c-.001.028-.008.054-.008.082 0 1.048.85 1.897 1.898 1.897h4.82v16.08a4.091 4.091 0 008.182 0v-16.08h2.326v16.08a4.09 4.09 0 008.182 0v-16.08h4.835a1.897 1.897 0 001.898-1.897c0-.028-.007-.055-.008-.082l.008-.002-.014-.051a1.887 1.887 0 00-.187-.698l-6.499-24.253.021-.006c-.027-.096-.06-.191-.06-.296 0-.616.5-1.118 1.118-1.118.525 0 .946.371 1.065.86l.043-.011 4.065 15.169.024-.007a3.53 3.53 0 006.819-1.292c0-.178-.027-.349-.052-.52l.055-.012z"
  })));
});
MaleFemale.displayName = 'MaleFemale';
export const MaleFemaleDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/MaleFemale/MaleFemale.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var MaleFemale = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("circle", {
    cx: 22.336,
    cy: 19.721,
    r: 8.272
  }), /*#__PURE__*/React.createElement("path", {
    d: "M37.999 30.217v-.04H8.363v.027a3.895 3.895 0 00-3.894 3.867h-.003V57.51h.039a3.477 3.477 0 106.954 0h.008V41.148h.009a1.104 1.104 0 011.101-1.064c.598 0 1.078.473 1.103 1.064h.009v42.905a4.067 4.067 0 008.136-.005V62.444h.03a1.127 1.127 0 112.253 0h.029v21.604a4.07 4.07 0 008.137 0v-42.9a1.11 1.11 0 112.222 0v16.363h.038a3.478 3.478 0 106.956 0h.007V34.072c.002-2.015-1.535-3.654-3.498-3.855z"
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 72.297,
    cy: 19.768,
    r: 8.32
  }), /*#__PURE__*/React.createElement("path", {
    d: "M95.534 54.161l-5.55-20.712c-.003-.016-.009-.032-.013-.048l-.098-.365-.014.004c-.506-1.579-1.968-2.729-3.715-2.729-.014 0-.026.004-.04.004v-.072h-26.12v.068c-1.747 0-3.209 1.151-3.715 2.729l-.014-.004-.098.364c-.004.017-.01.033-.013.05l-5.55 20.711.052.014c-.025.171-.052.342-.052.52a3.536 3.536 0 003.536 3.536 3.529 3.529 0 003.283-2.244l.025.007 4.071-15.193v.057h.032c.111-.5.536-.882 1.07-.882s.959.382 1.07.882h.033v.164c.002.025.015.047.015.072 0 .025-.013.047-.015.072v.155l-6.518 24.326a1.887 1.887 0 00-.187.698l-.014.051.008.002c-.001.028-.008.054-.008.082 0 1.048.85 1.897 1.898 1.897h4.82v16.08a4.091 4.091 0 008.182 0v-16.08h2.326v16.08a4.09 4.09 0 008.182 0v-16.08h4.835a1.897 1.897 0 001.898-1.897c0-.028-.007-.055-.008-.082l.008-.002-.014-.051a1.887 1.887 0 00-.187-.698l-6.499-24.253.021-.006c-.027-.096-.06-.191-.06-.296 0-.616.5-1.118 1.118-1.118.525 0 .946.371 1.065.86l.043-.011 4.065 15.169.024-.007a3.53 3.53 0 006.819-1.292c0-.178-.027-.349-.052-.52l.055-.012z"
  })));
});
MaleFemale.displayName = 'MaleFemale';
export var MaleFemaleDimensions = {
  height: 100,
  width: 100
};
